@@ -139,11 +139,11 @@ def test_tee_surface():
 @pytest.mark.skipif(not hasattr(sys, "getrefcount"), reason="PyPy")
 def test_image_surface_get_data_refcount():
     surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 10, 10)
-    assert sys.getrefcount(surface) == 2
+    refcount = sys.getrefcount(surface)
     d = surface.get_data()
-    assert sys.getrefcount(surface) == 3
+    assert sys.getrefcount(surface) != refcount
     del d
-    assert sys.getrefcount(surface) == 2
+    assert sys.getrefcount(surface) == refcount
 
 
 def test_image_surface_get_data_crasher():
@@ -267,7 +267,10 @@ def test_svg_version_to_string():
                     reason="too old cairo")
 def test_svg_surface_get_document_unit():
     with cairo.SVGSurface(None, 10, 10) as surface:
-        assert surface.get_document_unit() == cairo.SVGUnit.PT
+        # https://gitlab.freedesktop.org/cairo/cairo/-/issues/545
+        assert surface.get_document_unit() in [cairo.SVGUnit.PT, cairo.SVGUnit.USER]
+
+    with cairo.SVGSurface(None, 10, 10) as surface:
         surface.set_document_unit(cairo.SVGUnit.PX)
         assert surface.get_document_unit() == cairo.SVGUnit.PX
     with pytest.raises(cairo.Error):
@@ -487,7 +490,7 @@ def test_supports_mime_type():
         surface.supports_mime_type(object())
 
 
-# https://bitbucket.org/pypy/pypy/issues/2751
+# https://foss.heptapod.net/pypy/pypy/-/issues/2751
 @pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_image_surface_create_for_data_array():
     width, height = 255, 255
